<?php
// $Id: template.php,v 1.1.2.5 2010/05/21 18:22:37 dvessel Exp $

/**
 * Do not modify this file!
 *
 * Variables to avoid since it is in the same scope as phptemplate_init().
 *  - $template
 *  - $file
 * 
 * There are many more when including this file from "theme-settings.php".
 * Avoid using variables when possible.
 */


/**
 * Include required files.
 */
include_once 'includes/theme_meta.inc';
include_once 'includes/file_paths.inc';
include_once 'includes/plugins.inc';
include_once 'includes/markup_attributes.inc';
include_once 'includes/theme_hook_process.inc';


/**
 * Ensure the theme system is initialized before running the rest of this file.
 * The theme configuration page or theme api's "theme-settings.php" file will
 * include this and that is invoked very early in the process.
 */
init_theme();

/**
 * Clear theme caches and/or theme registry when set to do so.
 */
if ((int) hex_setting('disable_theme_caching', 0) == 1) {
  drupal_rebuild_theme_registry();
  hex_clear_cache();
}

/**
 * Invoke initialization function for themes and plug-ins.
 */
foreach (array_merge(hex_active_themes(), hex_plugin_list()) as $_prefix) {
  if (function_exists($_initfunc = $_prefix . '_init')) {
    $_initfunc();
  }
}

/**
 * Initialize the theme and rebuild caches when needed.
 */
function hex_init() {

  // See if the theme registry needs to be rebuilt.
  if ($registry_is_empty = !cache_get('theme_registry:' . hex_active_theme(), 'cache')) {
    include_once drupal_get_path('theme', 'hex') . '/includes/build_theme_registry.inc';

    hex_clear_cache();

    // Include necessary files for rebuilding the theme registry.
    foreach (hex_group_file_paths('init_include_registry_rebuild', 'all') as $file_path) {
      include_once $file_path;
    }
  }

  // Include general files.
  foreach (hex_group_file_paths('init_include', 'all') as $file_path) {
    include_once $file_path;
  }

  if ($registry_is_empty) {
    // Rebuild theme registry.
    _hex_build_registry();
  }
}


/**
 * Semiautomated caching. Use helper functions. Don't call directly.
 * 
 * Gets the cache for the given key. If none is available, a file name based
 * on the key is included. Then a function for building the cache data is called
 * (also named based on the key). The returned data is stored in the cache and
 * the data is returned.
 * 
 * @see hex_clear_cache()
 *  To clear the cache.
 */
function _hex_cache($key) {
  static $cache;

  if (!isset($cache[$key])) {
    if ($cache_from_key = cache_get("hex_$key:" . hex_active_theme())) {
      $cache[$key] = $cache_from_key->data;
    }
    else {
      // Build and store plugin data.
      include_once drupal_get_path('theme', 'hex') . "/includes/build_$key.inc";
      $cache[$key] = call_user_func("_hex_build_$key");
      cache_set("hex_$key:" . hex_active_theme(), $cache[$key]);
    }
  }

  return $cache[$key];
}

/**
 * Clears all caches or cache for the given key.
 */
function hex_clear_cache($key = NULL, $force_clear = FALSE) {
  static $cleared;

  // Prevent repeated clearings since it's a waste of cpu cycles.
  $clear_key = !isset($key) ? 'hex_' : "hex_$key";
  if (!isset($cleared[$clear_key]) || $force_clear) {
    cache_clear_all($clear_key, 'cache', TRUE);
  }
  $cleared[$clear_key] = TRUE;
}
